/***************************************************************************
 *   Copyright (C) 2005 by Roberto Cappuccio and the Kat team              *
 *   Roberto Cappuccio : roberto.cappuccio@gmail.com                       *
 *   Praveen Kandikuppa : praveen9@gmail.com                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
 ***************************************************************************/

#include <qwidget.h>
#include <qtooltip.h>

#include <klocale.h>
#include <kiconloader.h>
#include <kpopupmenu.h>
#include <kprocess.h>
#include "kattray.h"
#include <kdebug.h>
#include <dcopclient.h>
#include <kapplication.h>

KatTray::KatTray( QWidget* parent, const char* name )
    : KSystemTray( parent, name ), m_proc(0L)
{
    setPixmap( loadIcon( "kat" ) );

    int id = contextMenu()->idAt( 0 );
    QString tmp = i18n( "Kat Desktop Search Environment" );
    contextMenu()->changeTitle( id, SmallIcon( "kat" ), tmp );

    QToolTip::add( this, tmp );
    connect( this, SIGNAL( quitSelected() ), SLOT( slotQuitApp() ) );
}

KatTray::~KatTray()
{
	delete m_proc;
	m_proc = 0L;
}


void KatTray::mousePressEvent( QMouseEvent *e )
{
    if ( !rect().contains( e->pos() ) )
        return;
    if ( e->button() == LeftButton )
    {
	if( !m_proc)
		m_proc = new KProcess(this);
	m_proc->clearArguments();
	*m_proc << "kat";
        //*m_proc << "--searchmode";
        if( !m_proc->start())
	{
		delete m_proc;
		m_proc =0L;
	}

    }
    else
        KSystemTray::mousePressEvent( e );
}

void KatTray::slotQuitApp()
{
    QCStringList modules;
    QCString replyType;
    QByteArray replyData;

    if ( !kapp->dcopClient()->call( "kded", "kded", "loadedModules()", QByteArray(),
                                    replyType, replyData ) )
        return;
    else
    {
        if ( replyType == "QCStringList" ) {
            QDataStream reply( replyData, IO_ReadOnly );
            reply >> modules;
        }
    }
    QCStringList::ConstIterator end( modules.end() );
    for ( QCStringList::ConstIterator it = modules.begin(); it != end; ++it )
    {
        if ( *it == "katd" )
        {
            QCString service = "katd";
            QByteArray data, replyData;
            QCString replyType;
            QDataStream arg( data, IO_WriteOnly );
            arg << service;
            kapp->dcopClient()->call( "kded", "kded", "unloadModule(QCString)", data, replyType, replyData );
        }
    }
}

#include "kattray.moc"

